
.. _command_v2_api:

Commands V2 API
---------------

Objects in this package allow you to implement a robot using the 
latest version of WPILib's Command-based programming.  Command
based programming is a design pattern to help you organize your
robot programs, by organizing your robot program into components
based on :class:`.Command` and :class:`.Subsystem`

Each one of the objects in the Command framework has detailed
documentation available. If you need more information, for examples,
tutorials, and other detailed information on programming your robot
using this pattern, we recommend that you consult the Java version of the
`FRC Control System documentation <https://docs.wpilib.org/en/latest/docs/software/commandbased/index.html>`_


.. toctree::

  commands2
  commands2.button
  commands2.cmd
  commands2.sysid
